@@ -141,9 +141,9 @@
 
 #ifdef __linux__
 #if __BYTE_ORDER == __LITTLE_ENDIAN
-static NSString *unicharEncoding = @"UCS-2LE";
+static NSString *unicharEncoding = @"UTF-16LE";
 #else
-static NSString *unicharEncoding = @"UCS-2BE";
+static NSString *unicharEncoding = @"UTF-16BE";
 #endif /* __BYTE_ORDER */
 #else
 static NSString *unicharEncoding = @"UCS-2-INTERNAL";
@@ -209,7 +209,7 @@ static char *iconv_wrapper(id self, char *_src, unsigned _srcLen,
   tm           = outbuf;
   outbytesleft = outlen;
 
-  write = iconv(type, &inbuf, &inbytesleft, &tm, &outbytesleft);
+  write = iconv(type, (void*)&inbuf, &inbytesleft, &tm, &outbytesleft);
 
   if (write == (size_t)-1) {
     if (errno == EILSEQ) {
